==> akarixb-v0.3.tar.gz: akarixb-v0.3/src/globalobject.h <==
/*
 *   This file is part of AkariXB
 *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef GLOBALOBJECT_H
#define GLOBALOBJECT_H

#include <QObject>
#include <QSettings>
#include <QStringList>

#include <QDebug>

#include <QXmppClient.h>
#include <QXmppMucManager.h>


class GlobalObject : public QObject
{
    Q_OBJECT

public:
    explicit GlobalObject(QObject *parent = 0);
    ~GlobalObject();


    // General settings
    void syncGeneralSettings(QStringList newAdminJids,
                             QString newCommandPrefix);
    QStringList getAdminJids();
    QString getCommandPrefix();

    // Notification settings
    void syncNotificationSettings();

    // Systray settings
    void syncSystraySettings();


    //////////


    void setXmppClient(QXmppClient *client);
    QXmppClient *getXmppClient();

    void setMucManager(QXmppMucManager *mucManager);
    QXmppMucManager *getMucManager();

    void setDataDirectory(QString path);
    QString getDataDirectory();

    void addToLog(QString message, bool inStatusBar=true);

    void setConnected(bool state);
    bool connectedToServer();

    void addJoinedRoom(QString roomJid);
    void removeJoinedRoom(QString roomJid);
    QStringList getJoinedRooms();


signals:
    void logMessage(QString message);
    void showInStatusBar(QString message);


public slots:


private:
    QXmppClient *xmppClient;
    QXmppMucManager *xmppMucManager;

    QString dataDirectory;

    bool userConnected;

    QStringList joinedRooms;



    // General options
    QStringList adminJids;
    QString commandPrefix;


    // Notification options


    // Systray options


};

#endif // GLOBALOBJECT_H

==> akarixb-v0.4.tar.gz: akarixb-v0.4/src/globalobject.h <==
/*
 *   This file is part of AkariXB
 *   Copyright 2015-2016  JanKusanagi JRR <jancoding@gmx.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the
 *   Free Software Foundation, Inc.,
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
 */

#ifndef GLOBALOBJECT_H
#define GLOBALOBJECT_H

#include <QObject>
#include <QSettings>
#include <QStringList>

#include <QDebug>

#include <QXmppClient.h>
#include <QXmppMucManager.h>

#include "variableparser.h"


class GlobalObject : public QObject
{
    Q_OBJECT

public:
    explicit GlobalObject(QObject *parent = 0);
    ~GlobalObject();


    // General settings
    void syncGeneralSettings(QStringList newAdminJids,
                             QString newCommandPrefix,
                             int newKeepAliveTimeout);
    QStringList getAdminJids();
    QString getCommandPrefix();
    int getKeepAliveTimeout();

    // Notification settings
    void syncNotificationSettings(bool forNewChats,
                                  bool forDisconnection);
    bool getNotifyNewChats();
    bool getNotifyDisconnection();

    // Systray settings
    void syncSystraySettings();


    //////////


    void setXmppClient(QXmppClient *client);
    QXmppClient *getXmppClient();

    void setMucManager(QXmppMucManager *mucManager);
    QXmppMucManager *getMucManager();

    void setVariableParser(VariableParser *varParser);
    VariableParser *getVariableParser();

    void setDataDirectory(QString path);
    QString getDataDirectory();


    //////////


    void addToLog(QString message, bool inStatusBar=true);
    void showNotification(QString title, QString message);

    void setConnected(bool state);
    bool connectedToServer();

    void addJoinedRoom(QString roomJid);
    void removeJoinedRoom(QString roomJid);
    QStringList getJoinedRooms();

    QXmppMucRoom *roomFromJid(QString roomJid);


    void notifyActivityChange(QString name, QString timeRange);
    void notifyStatusMessageChange(QString text);


    void sendMessageToJid(QString jid, QString message);



signals:
    void logMessage(QString message);
    void showInStatusBar(QString message);
    void showNotificationPopup(QString title, QString message);

    void activityChanged(QString activityInfo);
    void statusMessageChanged(QString text);


public slots:


private:
    QXmppClient *xmppClient;
    QXmppMucManager *xmppMucManager;

    VariableParser *variableParser;


    QString dataDirectory;

    bool userConnected;

    QStringList joinedRooms;



    // General options
    QStringList adminJids;
    QString commandPrefix;
    int keepAliveTimeout;


    // Notification options
    bool notifyNewChats;
    bool notifyDisconnection;


    // Systray options


};

#endif // GLOBALOBJECT_H
